@@ -23,6 +23,7 @@
 #include "ephy-favicon-cache.h"
 #include "mozilla-embed-single.h"
 #include "ephy-debug.h"
+#include "downloader-view.h"
 
 #include <string.h>
 
@@ -129,25 +130,11 @@ ephy_embed_single_finalize (GObject *object)
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-EphyEmbedSingle *
-ephy_embed_single_new (const char *type)
-{
-	if (strcmp (type, "mozilla") == 0)
-	{
-		return EPHY_EMBED_SINGLE (g_object_new
-			(MOZILLA_EMBED_SINGLE_TYPE, NULL));
-	}
-
-	g_assert_not_reached ();
-	return NULL;
-}
-
 gresult
-ephy_embed_single_clear_cache (EphyEmbedSingle *shell,
-			      CacheType type)
+ephy_embed_single_clear_cache (EphyEmbedSingle *shell)
 {
 	EphyEmbedSingleClass *klass = EPHY_EMBED_SINGLE_GET_CLASS (shell);
-        return klass->clear_cache (shell, type);
+        return klass->clear_cache (shell);
 }
 
 gresult
